/**
 * @(#) AdminServiceMBean.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: AdminServiceMBean.java 221 2006-04-14 12:45:33Z alouis $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.management;

/**
 * This interface defines a set of administrative methods allowing a JMX-based
 * administrative tool to perform a variety of administrative tasks.
 * <ul>
 *   <li>Find component lifecycle MBean names for:
 *     <ul>
 *       <li>Individual components, by name
 *       <li>All binding components
 *       <li>All service engines
 *     </ul>
 *   <li>Find lifecyle MBeans names for implementation-defined services:
 *     <ul>
 *       <li>Individual implementation services, by name
 *       <li>All implementation services
 *     </ul>
 *   <li>Query whether an individual component is a binding or engine
 *   <li>Query implementation information (version etc.)
 * </ul> 
 *
 * @author JSR208 Expert Group
 */
public interface AdminServiceMBean {

	/**
     * Get a list of all {@link ComponentLifeCycleMBean}s binding components
     * currently installed in the JBI system.
     * 
     * @return array of JMX object names of component life cycle MBeans for all
     *         installed binding components; must be non-null; may be empty
     */
	public javax.management.ObjectName[] getBindingComponents();

	/**
     * Find the {@link ComponentLifeCycleMBean} of a JBI Installable Component
     * by its unique name.
     * 
     * @param name
     *            the name of the engine or binding component; must be non-null
     *            and non-empty
     * @return the JMX object name of the component's life cycle MBean, or
     *         <code>null</code> if there is no such component with the given
     *         <code>name</code>
     */
    public javax.management.ObjectName getComponentByName(
            java.lang.String name);

	/**
     * Get a list of all {@link ComponentLifeCycleMBean}s for all service
     * engines currently installed in the JBI system.
     * 
     * @return array of JMX object names of component life cycle MBeans for all
     *         installed service engines; must be non-null; may be empty
     */
	public javax.management.ObjectName[] getEngineComponents();

	/**
     * Return current version and other info about this JBI implementation. The
     * contents of the returned string are implementation dependent.
     * 
     * @return information string about the JBI implementation, including
     *         version information; must be non-null and non-empty
     */
	public java.lang.String getSystemInfo();

	/**
     * Lookup a system service {@link LifeCycleMBean} by name. System services
     * are implementation-defined services which can administered through JMX,
     * and have a life cycle.
     * <p>
     * System services are not related to service engines.
     * 
     * @param serviceName
     *            name of the system service; must be non-null and non- empty;
     *            values are implementation-dependent
     * @return JMX object name of the system service's LifeCycleMBean, or
     *         <code>null</code> if there is no system service with the given
     *         <code>name</code>.
     */
	public javax.management.ObjectName getSystemService(
			java.lang.String serviceName);

	/**
     * Looks up all JBI system services {@link LifeCycleMBean}'s currently
     * installed. System services are implementation-defined services which can
     * administered through JMX. System services are not related to service
     * engines.
     * 
     * @return array of LifecycleMBean JMX object names of system services
     *         currently installed in the JBI implementation; must be non-null;
     *         may be empty
     */
	public javax.management.ObjectName[] getSystemServices();

	/**
     * Check if a given JBI Component is a Binding Component.
     * 
     * @param componentName
     *            the unique name of the component; must be non-null and
     *            non-empty
     * @return <code>true</code> if the component is a binding component;
     *         <code>false</code> if the component is a service engine or if
     *         there is no component with the given <code>componentName</code>
     *         installed in the JBI system
     */
	public boolean isBinding(java.lang.String componentName);

	/**
     * Check if a given JBI Component is a Service Engine.
     * 
     * @param componentName
     *            the unique name of the component; must be non-null and
     *            non-empty
     * @return <code>true</code> if the component is a binding component;
     *         <code>false</code> if the component is a service engine or if
     *         there is no component with the given <code>componentName</code>
     *         installed in the JBI system
     */
	public boolean isEngine(java.lang.String componentName);
}
